<?php

if ( ! function_exists( 'vantage_content_nav' ) ) :
/**
 * Display navigation to next/previous pages when applicable
 *
 * @since vantage 1.0
 */
function vantage_content_nav( $nav_id ) {
global $wp_query, $post;

// Don't print empty markup on single pages if there's nowhere to navigate.
if ( is_single() ) {
$previous = ( is_attachment() ) ? get_post( $post->post_parent ) : get_adjacent_post( false, '', true );
$next = get_adjacent_post( false, '', false );

if ( ! $next && ! $previous )
return;
}

// Don't print empty markup in archives if there's only one page.
if ( $wp_query->max_num_pages < 2 && ( is_home() || is_archive() || is_search() ) )
return;

// Add the shorten title filter
add_filter('the_title', 'vantage_content_nav_shorten_title');

$nav_class = 'site-navigation paging-navigation';
if ( is_single() )
$nav_class = 'site-navigation post-navigation';

?>
<nav role="navigation" id="<?php echo esc_attr( $nav_id ); ?>" class="<?php echo $nav_class; ?>">

<?php if ( is_single() ) : // navigation links for single posts ?>

<div class="single-nav-wrapper">
<?php if ( function_exists( 'wp_pagenavi' ) ) wp_pagenavi(); ?>
</div>

<?php elseif ( $wp_query->max_num_pages > 1 && ( is_home() || is_archive() || is_search() ) ) : // navigation links for home, archive, and search pages ?>

<?php vantage_pagination() ?>

<?php endif; ?>

</nav><!-- #<?php echo esc_html( $nav_id ); ?> -->
<?php

// Remove the shorten title filter
remove_filter('the_title', 'vantage_content_nav_shorten_title');
}
endif; // vantage_content_nav

if(!function_exists('vantage_display_logo')):
/**
 * Display the logo 
 */
function vantage_display_logo(){
$logo = siteorigin_setting( 'logo_image' );
$logo = apply_filters('vantage_logo_image_id', $logo);

if( empty($logo) ) {
// Just display the site title
$logo_html = '<span class="site-title">'.get_bloginfo( 'name' ).'</span>';
$logo_html = apply_filters('vantage_logo_text', $logo_html);
}
else {
// load the logo image
if(is_array($logo)) {
list ($src, $height, $width) = $logo;
}
else {
$image = wp_get_attachment_image_src($logo, 'full');
$src = $image[0];
$height = $image[2];
$width = $image[1];
}

// Add all the logo attributes
$logo_attributes = apply_filters('vantage_logo_image_attributes', array(
'src' => $src,
'width' => round($width),
'height' => round($height),
'alt' => sprintf( __('%s Logo', 'vantage'), get_bloginfo('name') ),
) );

if($logo_attributes['width'] > vantage_get_site_width()) {
// Don't let the width be more than the site width.
$width = vantage_get_site_width();
$logo_attributes['height'] = round($logo_attributes['height'] / ($logo_attributes['width'] / $width));
$logo_attributes['width'] = $width;
}

$logo_attributes_str = array();
if( !empty( $logo_attributes ) ) {
foreach($logo_attributes as $name => $val) {
if( empty($val) ) continue;
$logo_attributes_str[] = $name.'="'.esc_attr($val).'" ';
}
}

$logo_html = apply_filters('vantage_logo_image', '<img '.implode( ' ', $logo_attributes_str ).' />');
}

// Echo the image
echo apply_filters('vantage_logo_html', $logo_html);
}
endif;

function new_excerpt_more($more) {
    global $post;
    return '… <a href="'. get_permalink($post->ID) . '">' . __('(далее...)', 'vantage') . '</a>';
}
add_filter('excerpt_more', 'new_excerpt_more');